package logic

import (
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"fusenapi/utils/ldap_lib"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type CreateLdapUserBaseGroupLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewCreateLdapUserBaseGroupLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CreateLdapUserBaseGroupLogic {
	return &CreateLdapUserBaseGroupLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *CreateLdapUserBaseGroupLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *CreateLdapUserBaseGroupLogic) CreateLdapUserBaseGroup(req *types.Request, userinfo *auth.UserInfo) (resp *basic.Response) {
	ldapServer := ldap_lib.NewLdap(l.svcCtx.Ldap, l.svcCtx.Config.Ldap.BaseDN, l.svcCtx.Config.Ldap.RootDN)
	err := ldapServer.Create(l.svcCtx.Config.Ldap.PeopleGroupDN, map[string][]string{
		"objectClass":      {"top", "organizationalUnit"},
		"ou":               {"FusenTeam"},
		"businessCategory": {"FUSEN团队"},
	})
	if err != nil {
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeServiceErr, "创建用户基础分组失败,"+err.Error())
	}
	return resp.SetStatusWithMessage(basic.CodeServiceErr, "创建用户基础分组成功")
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *CreateLdapUserBaseGroupLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
